@@ -9,7 +9,6 @@ from whichcraft import which
 from duckietown_challenges import InvalidEnvironment
 from . import logger
 from .exceptions import UserError
-from .shell_config import read_shell_config
 
 
 def running_with_sudo() -> bool:
@@ -132,24 +131,3 @@ def get_active_groups(username: Optional[str] = None) -> List[str]:
     active_groups = stdout.decode().split()
 
     return active_groups
-
-
-def get_dockerhub_username() -> str:
-    """ raise InvalidEnvironment """
-    try:
-        shell_config = read_shell_config()
-    except Exception:
-        msg = "Please set docker username using\n\n dts challenges config --docker-username <USERNAME>"
-        raise InvalidEnvironment(msg)
-    #
-    # if shell is None:
-    #     from .cli import DTShell
-    #     shell = DTShell()
-    # k = DTShellConstants.CONFIG_DOCKER_USERNAME
-    # if k not in shell.config:
-
-    if shell_config.docker_username is None:
-        msg = "Please set docker username using\n\n dts challenges config --docker-username <USERNAME>"
-        raise InvalidEnvironment(msg)
-
-    return shell_config.docker_username
