@@ -17,19 +17,26 @@ from zuper_commons.text import indent
 from zuper_commons.timing import now_utc
 from zuper_commons.types import ZValueError
 
+from dt_shell import ConfigNotPresent
+from dt_shell.config import get_shell_config_default, read_shell_config
 from duckietown_build_utils import (
     BuildFailed,
     DockerCompleteImageName,
+    DockerCredentials,
+    DockerRegistryName,
     get_duckietown_labels,
     get_important_env_build_args_dict,
+    pull_for_build,
     run_build,
     update_versions,
 )
+from duckietown_build_utils.docker_building import log_in_for_build
 from duckietown_challenges import (
     CHALLENGE_PREVIOUS_STEPS_DIR,
     ChallengeResults,
     dtserver_get_compatible_challenges,
     get_challenge_description,
+    get_registry_info,
     List,
     read_submission_info,
     SubmissionID,
@@ -38,7 +45,7 @@ from duckietown_challenges import (
 from duckietown_challenges.utils import tag_from_date
 from . import logger
 from .exceptions import UserError
-from .runner import get_token_from_shell_config, run_single
+from .runner import run_single
 from .submission_build import submission_build3
 
 usage = """
@@ -66,7 +73,7 @@ def runner_local_main():
         sys.exit(2)
 
 
-def runner_local_main_(args: List[str] = None, token: str = None, docker_username: str = "dummy-user"):
+def runner_local_main_(args: List[str] = None, token: str = None):
     if args is None:
         from duckietown_challenges.col_logging import setup_logging_color
 
@@ -115,13 +122,20 @@ def runner_local_main_(args: List[str] = None, token: str = None, docker_usernam
             raise ZValueError(msg, curdir=curdir, tochange=parsed.change)
         os.chdir(parsed.change)
 
+    try:
+        shell_config = read_shell_config()
+    except (ConfigNotPresent) as e:
+        msg = f"Cannot find shell config: {e}"
+        logger.warning(msg)
+        shell_config = get_shell_config_default()
     if token is None:
-        token = get_token_from_shell_config()
+        token = shell_config.token_dt1
 
     path = "."
 
     sub_info = read_submission_info(path)
-
+    ri = get_registry_info(token=token, impersonate=parsed.impersonate)
+    registry = cast(DockerRegistryName, ri.registry)
     compat = dtserver_get_compatible_challenges(
         token=token, impersonate=parsed.impersonate, submission_protocols=sub_info.protocols, quiet=quiet,
     )
@@ -187,10 +201,10 @@ For example, you could try:
 
     # tag = cast(DockerCompleteImageName, "dummy-org/dummy-repo")
     # TODO: change the build procedure
-    username = "dummy-org"
-    registry = "docker.io"
-
-    solution_container = submission_build3(username, registry, no_cache)
+    credentials = cast(DockerCredentials, shell_config.docker_credentials)
+    solution_container = submission_build3(
+        credentials=credentials, registry=registry, no_cache=no_cache, pull=do_pull
+    )
 
     # image = build_image(
     #     client, tag=tag, path=path, dockerfile=dockerfile, no_cache=no_cache, no_build=no_build,
@@ -277,7 +291,7 @@ For example, you could try:
         aws_config = None
         steps2artefacts = {}
         evaluation_parameters = step.evaluation_parameters
-        server_host = None
+        # server_host = None
         if "CONTAINER_PREFIX" in os.environ:
             prefix = os.environ["CONTAINER_PREFIX"]
             # logger.debug(f"will respect CONTAINER_PREFIX = {prefix!r} ")
@@ -306,7 +320,7 @@ For example, you could try:
             do_pull=do_pull,
             debug_volumes=parsed.debug_volumes,
             timeout_sec=step.timeout,
-            server_host=server_host,
+            # server_host=server_host,
             require_scores=require_scores,
             quota_cpu=quota_cpu,
             quiet=quiet,
@@ -314,6 +328,7 @@ For example, you could try:
             steps2scores=steps2scores,
             submitter_name=submitter_name,
             evaluator_name=evaluator_name,
+            credentials=credentials,
         )
 
         fn = os.path.join(wd, "results.yaml")
@@ -341,9 +356,15 @@ def dark(x):
     return termcolor.colored(x, attrs=["dark"])
 
 
-def submission_build_2(username: str, registry: str, no_cache: bool = False) -> DockerCompleteImageName:
+def submission_build_2(
+    registry: DockerRegistryName, no_cache: bool, credentials: DockerCredentials
+) -> DockerCompleteImageName:
     tag = tag_from_date(now_utc())
     df = "Dockerfile"
+    if registry not in credentials:
+        msg = f"Need credentials for {registry!r}"
+        raise ZValueError(msg, known=list(credentials))
+    username = credentials[registry]["username"]
     organization = username.lower()
     # repository = "aido-submissions"
     repository = "dummy-repo"
@@ -367,8 +388,10 @@ def submission_build_2(username: str, registry: str, no_cache: bool = False) ->
     df_contents = read_ustring_from_utf8_file(df)
 
     build_vars = get_important_env_build_args_dict(df_contents)
+    log_in_for_build(df_contents, credentials)
+    pull_for_build(client, df_contents, credentials, quiet=False)
     args = dict(
-        path=path, tag=complete_image, pull=True, buildargs=build_vars, labels=labels, nocache=no_cache
+        path=path, tag=complete_image, pull=False, buildargs=build_vars, labels=labels, nocache=no_cache
     )
     try:
         run_build(client, **args)
